pub struct EdgeRecord {
pub src: NodeId,
pub dst: NodeId,
pub edge_type: TypeId,
pub props: Vec<u8>,
}Expand description
Stored in the edges LMDB sub-database as msgpack bytes.
Fields
src: NodeIddst: NodeIdedge_type: TypeIdprops: Vec<u8>Trait Implementations
Sourceimpl Clone for EdgeRecord
impl Clone for EdgeRecord
Sourcefn clone(&self) -> EdgeRecord
fn clone(&self) -> EdgeRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EdgeRecord
impl Debug for EdgeRecord
Sourceimpl DeepSizeOf for EdgeRecord
impl DeepSizeOf for EdgeRecord
Sourcefn deep_size_of_children(&self, context: &mut Context) -> usize
fn deep_size_of_children(&self, context: &mut Context) -> usize
Returns an estimation of the heap-managed storage of this object.
This does not include the size of the object itself. Read more
Sourcefn deep_size_of(&self) -> usize
fn deep_size_of(&self) -> usize
Returns an estimation of a total size of memory owned by the
object, including heap-managed storage. Read more
Sourceimpl<'de> Deserialize<'de> for EdgeRecord
impl<'de> Deserialize<'de> for EdgeRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more