pub struct NeighborEntry {
pub node: NodeId,
pub edge: EdgeId,
pub edge_type: TypeId,
}Expand description
The result of a single adjacency lookup entry returned by
crate::Graph::out_neighbors and crate::Graph::in_neighbors.
Fields
node: NodeIdedge: EdgeIdedge_type: TypeIdTrait Implementations
Sourceimpl Clone for NeighborEntry
impl Clone for NeighborEntry
Sourcefn clone(&self) -> NeighborEntry
fn clone(&self) -> NeighborEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NeighborEntry
impl Debug for NeighborEntry
Sourceimpl PartialEq for NeighborEntry
impl PartialEq for NeighborEntry
Sourcefn eq(&self, other: &NeighborEntry) -> bool
fn eq(&self, other: &NeighborEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NeighborEntry