pub struct WeightedPath {
pub nodes: Vec<NodeId>,
pub total_weight: f64,
}Expand description
A path with an associated total weight, returned by weighted path algorithms.
Fields
nodes: Vec<NodeId>total_weight: f64Trait Implementations
Sourceimpl Clone for WeightedPath
impl Clone for WeightedPath
Sourcefn clone(&self) -> WeightedPath
fn clone(&self) -> WeightedPath
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WeightedPath
impl Debug for WeightedPath
Sourceimpl PartialEq for WeightedPath
impl PartialEq for WeightedPath
Sourcefn eq(&self, other: &WeightedPath) -> bool
fn eq(&self, other: &WeightedPath) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WeightedPath